@@ -18,19 +18,18 @@ def list_col_to_df(df,col_name,key='name',value='value',drop_col=True):
   return df
 
 def expand_df(df,key='',value=''):
-
   while True:
     no_of_dicts=0
-    if len(df)>0:
+    if len(df) > 0:
       for i in df.columns:
-        if type(df[i][0])==dict:
-          no_of_dicts+=1
-          df = json_col_to_df(df,i)
-        elif type(df[i][0])==list and key:
-          no_of_dicts+=1
-          df = list_col_to_df(df,i,key=key,value=value)
+        if len(df)>0:
+          if type(df[i][0])==dict:
+            no_of_dicts+=1
+            df = json_col_to_df(df,i)
+          elif type(df[i][0])==list and key:
+            no_of_dicts+=1
+            df = list_col_to_df(df,i,key=key,value=value)
 
-          
     if no_of_dicts==0:
       break
     
@@ -520,7 +519,6 @@ class SofaScore:
     res = expand_df(pd.DataFrame(res))
     return res
 
-
   # Get a list of players (and their basic stats)
   def get_players(tournament=17, season=29415,limit=20,order='-rating',offset=20,group='summary'):
 
@@ -543,9 +541,11 @@ class SofaScore:
     }
 
     response = requests.request("GET", url, headers=headers, data = payload)
-
-    res = json.loads(response.text.encode('utf8'))
-    return res
+    try:
+      res = json.loads(response.text.encode('utf8'))
+      return res
+    except:
+      return {"error":"oops"}
 
 
   # Get detailed stats for one player
